Learn R Programming

EIEntropy (version 0.0.1.3)

financial: Randomly Generated Data

Description

This dataset contains 100 observations of 6 variables. The data was generated randomly for the purpose of exemplifying a database that could potentially be used with this function.

Usage

financial()

Arguments

Value

A data frame containing the loaded "financial" data from the .rds file.

  • Dcollege: Dummy variable indicating college education.

  • Dunemp: Dummy variable indicating unemployment.

  • Totalincome: Total income of each observation.

  • poor_liq: Dummy variable indicating liquid poverty.

  • w: Weights for each observation.

  • n: Identifier for observations.

Format

A data frame with 100 observations of 6 variables called financial

Examples

Run this code
data(financial)
head(financial)


Run the code above in your browser using DataLab