Learn R Programming

EIEntropy (version 0.0.1.3)

summary.kl: Summary

Description

This function provides a summary of the output obtained with the function ei_gce.

Usage

# S3 method for kl
summary(object, ...)

Value

This summary function returns the Kullback-Leibler divergence value and the last iteration in the optimization process. A dataframe with the means of the estimations for each characteristic j with the predictions the probabilities and the error estimated. A dataframe with the lambda estimated for each k.

  • Iterations:Indicates the times the objective function and the gradient has been evaluated during the optimization process

  • divergencekl value:The Kullback-Leibler divergence value resulting from the optimization.

  • mean_estimations:The weighted mean of predictions, p_dual, and the error for each category j of the variable y

  • lambda:The estimated lambda values.

Arguments

object

The output obtained from ei_gce

...

Additional arguments passed to the summary function.