This function provides a summary of the output obtained with the function ei_gme.
# S3 method for shannon
summary(object, ...)This summary function returns the entropy value and the last iteration in the optimization process. A dataframe with the means of the estimations for each characteristic j with the predictions the probabilities and the error estimated. A dataframe with the lambda estimated for each k.
Iterations:Indicates the times the objective function and the gradient has been evaluated during the optimization process
Entropy value:The value of entropy resulting from the optimization.
mean_estimations: The weighted mean of predictions, p_dual, and the error for each category j of the variable y
lambda:The estimated lambda values.
The output obtained from ei_gme
Additional arguments passed to the summary function.