This dataset contains 200 observations of 6 variables. The data was generated randomly for the purpose of exemplifying a database that could potentially be used with this function.
social()A data frame containing the loaded "social" data from the .rds file.
Dcollege: Dummy variable indicating college education.
Dunemp: Dummy variable indicating unemployment.
Totalincome: Total income of each observation.
reg:Variable indicating the region of the observation.
w: Weights for each observation.
n: Identifier for observations.
#' @examples data(social) head(social)
A data frame with 200 observations of 6 variables called social